#!/bin/ksh
#> This script will install F5 BigIP components
#> patch: 9.1.1.0.22
#> Usage: install.sh {-help | -install | -uninstall}
#

# Required values defined
export PATCH_VER=9.1.1.0.22
export START_DIR=`pwd`
export SOURCE_DIR=${FLEXPM_BASE}/patches/${PATCH_VER}
export BACKUP_DIR=$START_DIR/Backup

# **************************************************************
# The following are 'standard' routines to be used before
# attempting to apply and upgrade/patch
# **************************************************************
# ***
# Check the essential environment settings have been defined before attempting
# any installation procedures.
# ***
function CheckEnvironment {

  # Check FLEXPM_HOME is defined 
  if [[ -z ${FLEXPM_HOME} || ! -d ${FLEXPM_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check PROSPECT_HOME is defined 
  if [[ -z ${PROSPECT_HOME} || ! -d ${PROSPECT_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check F5BigIP_HOME is defined 
  if [[ -z ${F5BigIP_HOME} || ! -d ${F5BigIP_HOME} ]]; then
    echo ""
    echo "+> Env variable F5BigIP_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check that the DB_CONNECT string is defined.
  if [[ -z ${DB_CONNECT} ]]; then
    echo ""
    echo "+> Env variable DB_CONNECT must be set to approriate database connection values."
    echo ""
    exit 1;
  fi
  # Check VENDOR pre-requisite
  PRE_REQ=`show_installed | grep 'F5BigIP rev 9.1.1.0.21'`
  if [[ -z ${PRE_REQ} ]]; then
    echo ""
    echo "+> F5BigIP 9.1.1.0.21 must be installed before applying this patch."
    echo ""
    exit 1;
  fi
}

# **************************************************************
# End of routines and start of main patch
# **************************************************************

# Check that the passed parameters are correct
if [[ $# -ne 1 ]]; then
  echo
  echo
  echo "Usage : $0 {-help | -install | -uninstall}"
  echo
  exit;
fi

case $1 in
  -install)
    echo ""
    date +"+ Patch install started at %T, %D ..."
    echo ""

    # Check env settings
    echo ""
    echo "+ Checking environment ..."
    CheckEnvironment
    echo "+ Environment appears to be OK ..."
    echo ""

    # Install updated components
    if [ ! -d $BACKUP_DIR ]
    then
      mkdir $BACKUP_DIR
    fi

    echo "Registering F5BigIP ${PATCH_VER} ..."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SOURCE_DIR}/F5BigIP.build

    ########################################################
    echo "+ Installing updated files..."
    ########################################################

    cd $SOURCE_DIR/sources

    for new_dir in `find . -type d|cut -c3-`
    do
        if [[ -d ${FLEXPM_BASE}/$new_dir ]]; then
          echo "dir ok: $new_dir"
        else
          echo "create: $new_dir"
          mkdir -p ${FLEXPM_BASE}/$new_dir
        fi
    done

    touch ${BACKUP_DIR}/backup_sources.tar

    cd $SOURCE_DIR/sources

    for new_file in `find . -type f|cut -c3-`
    do
        cd ${FLEXPM_BASE}
        if [[ -f $new_file ]];
        then
          echo "backup: ${FLEXPM_BASE}/$new_file"
          tar -uf ${BACKUP_DIR}/backup_sources.tar $new_file
          chmod +w $new_file
        fi
        echo "update: ${FLEXPM_BASE}/$new_file"
        cp -p ${SOURCE_DIR}/sources/$new_file $new_file
    done

    echo "Completing registration ..."
    register complete ${SOURCE_DIR}/F5BigIP.build

    cd ${START_DIR}

    date +"Patch is completed at %T, %D ....."
    echo
    break
    ;;
  -uninstall)

    cd ${FLEXPM_BASE}

    if [[ -f ${BACKUP_DIR}/backup_sources.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `tar -tf ${BACKUP_DIR}/backup_sources.tar`
      do
         if [ -f $file ]
         then
           chmod +w $file
         fi
      done
      tar -xf ${BACKUP_DIR}/backup_sources.tar
    fi

    rm -rf ${BACKUP_DIR}

      #Remove the component registration for this patch
      COMP_REG=`show_installed | grep '9.1.1.0.22'`
      if [[ ! -z ${COMP_REG} ]]; then
sq1="select component_version_id from component_version where revision = '9.1.1.0.22' and component_id = (select component_id from component where component_name = 'F5BigIP')"
sq2="delete component_history where component_version_id = ( $sq1 )"
sq3="delete component_installed where component_version_id = ( $sq1 )"
sq4="delete component_version where component_version_id = ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq2};
${sq3};
${sq4};
exit;
EOF
      fi

    cd ${START_DIR}

    date +"Patch uninstall is completed at %T, %D ....."
    echo
    break
    ;;
  -help)
    echo
    echo "Usage : $0 {-help | -install | -uninstall}"
    echo
    echo "-help      : Display this help text"
    echo "-install   : Install the patch"
    echo "-uninstall : Uninstall the patch"
    echo
    break
    ;;
  *)
    echo
    echo "Invalid argument supplied"
    echo
    echo "Usage : $0 {-help | -install | -uninstall}"
    echo
    break
    ;;
esac

